@@ -13,7 +13,7 @@ import (
 	"github.com/pkg/errors"
 )
 
-var reFK = regexp.MustCompile(`FOREIGN KEY \((.+)\) REFERENCES ([^\s]+)\s?\((.+)\)`)
+var reFK = regexp.MustCompile(`FOREIGN KEY \((.+)\) REFERENCES ([^\s\)]+)\s?\(([^\)]+)\)`)
 var reFTS = regexp.MustCompile(`(?i)USING\s+fts([34])`)
 
 var shadowTables []string
@@ -362,13 +362,7 @@ SELECT name, sql FROM sqlite_master WHERE type = 'trigger' AND tbl_name = ?;
 
 	// Relations
 	for _, r := range relations {
-		result := reFK.FindAllStringSubmatch(r.Def, -1)
-		if len(result) < 1 || len(result[0]) < 4 {
-			return errors.Errorf("can not parse foreign key: %s", r.Def)
-		}
-		strColumns := strings.Split(result[0][1], ", ")
-		strParentTable := result[0][2]
-		strParentColumns := strings.Split(result[0][3], ", ")
+		strColumns, strParentTable, strParentColumns, err := parseFK(r.Def)
 		for _, c := range strColumns {
 			column, err := r.Table.FindColumnByName(c)
 			if err != nil {
@@ -499,3 +493,14 @@ func contains(s []string, e string) bool {
 	}
 	return false
 }
+
+func parseFK(def string) ([]string, string, []string, error) {
+	result := reFK.FindAllStringSubmatch(def, -1)
+	if len(result) < 1 || len(result[0]) < 4 {
+		return nil, "", nil, errors.Errorf("can not parse foreign key: %s", def)
+	}
+	strColumns := strings.Split(result[0][1], ", ")
+	strParentTable := strings.Trim(result[0][2], `"`)
+	strParentColumns := strings.Split(result[0][3], ", ")
+	return strColumns, strParentTable, strParentColumns, nil
+}
